API docs for “spamfighter.core.storage.memory.DomainMemoryStorage”

# Class s.c.s.m.DomainMemoryStorage(object):

Part of spamfighter.core.storage.memory View Source View In Hierarchy

Хранилище в памяти, которое располагается в домене.

Все хранилища в доменах разделяют один общий экземпляр `MemoryStorage`, префиксируя доступ к ключам ключом домена.

Method | __init__ | Undocumented
Method | bind | Извещение объекту о том, что он был помещен в домен.
Method | set | Undocumented
Method | get | Undocumented
Method | add | Undocumented
Method | append | Undocumented
Method | incr | Undocumented
Method | delete | Undocumented
Method | __getstate__ | Undocumented
Method | __setstate__ | Undocumented

def __init__(self, storage=None): (source)
Undocumented
def bind(self, domain, name): (source)
Извещение объекту о том, что он был помещен в домен.

Parameters | domain | домен (type: `IDomain` )
| name | имя в домене (type: `str` )

def set(self, key, value, expire): (source)
Undocumented
def get(self, key): (source)
Undocumented
def add(self, key, value, expire): (source)
Undocumented
def append(self, key, value): (source)
Undocumented
def incr(self, key, value=1): (source)
Undocumented
def delete(self, key): (source)
Undocumented
def __getstate__(self): (source)
Undocumented
def __setstate__(self, state): (source)
Undocumented